==> localnews-quartz-service-1.0.9-sources.jar: com/bxm/localnews/quartz/service/impl/NewsQuartzServiceImpl.java <==
package com.bxm.localnews.quartz.service.impl;

import com.alibaba.fastjson.JSON;
import com.bxm.localnews.mq.common.constant.PushMessageEnum;
import com.bxm.localnews.mq.common.model.dto.PushMessage;
import com.bxm.localnews.mq.common.model.dto.PushPayloadInfo;
import com.bxm.localnews.mq.common.model.dto.PushReceiveScope;
import com.bxm.localnews.quartz.constant.NewsStatusEnum;
import com.bxm.localnews.quartz.domain.NewsQuartzMapper;
import com.bxm.localnews.quartz.facade.PushMsgIntegService;
import com.bxm.localnews.quartz.integration.NewsIntegrationService;
import com.bxm.localnews.quartz.service.NewsQuartzService;
import com.bxm.localnews.quartz.vo.News;
import com.bxm.localnews.quartz.vo.NewsSearchWordBean;
import com.bxm.localnews.quartz.vo.RecommendNewsBean;
import org.apache.commons.lang.StringUtils;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class NewsQuartzServiceImpl implements NewsQuartzService {

    private static final Logger logger = LoggerFactory.getLogger(NewsQuartzServiceImpl.class);

    private static String url = "http://top.baidu.com/buzz?b=1&fr=topindex";

    private static String userAgent = "User-Agent";

    private static String value = "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/52.0.2743.116 Safari/537.36";

    private NewsQuartzMapper newsQuartzMapper;

    private PushMsgIntegService pushMsgIntegService;

    private NewsIntegrationService newsIntegrationService;

    @Autowired(required = false)
    public NewsQuartzServiceImpl(NewsQuartzMapper newsQuartzMapper,
                                 PushMsgIntegService pushMsgIntegService,
                                 NewsIntegrationService newsIntegrationService) {
        this.newsQuartzMapper = newsQuartzMapper;
        this.pushMsgIntegService = pushMsgIntegService;
        this.newsIntegrationService = newsIntegrationService;
    }

    private List<NewsSearchWordBean> loadHotword() {
        List<NewsSearchWordBean> list = new ArrayList<>();
        try {
            Document doc = Jsoup.connect(url).header(userAgent, value).timeout(5000).get();
            Elements elements = doc.select(".keyword");
            for (Element e : elements) {
                if (e == null) {
                    continue;
                }
                Element ee = e.lastElementSibling();
                String name = e.select("a:eq(0)").text();
                String number = ee.select("span").text();
                NewsSearchWordBean word = new NewsSearchWordBean();
                word.setName(name);
                word.setNumber(Integer.valueOf(number));
                list.add(word);
                if (list.size() >= 10) {
                    break;
                }
            }
        } catch (Exception e) {
            logger.error("---抓取热点新闻标题异常---");
        }
        return list;
    }

    @Override
    public void createHotword() {
        List<NewsSearchWordBean> searchWords = loadHotword();
        if (searchWords.size() > 8) {
            newsQuartzMapper.delete();
            newsQuartzMapper.insertBatch(searchWords);
        }
    }

    @Override
    public void execWakeup() {
        List<RecommendNewsBean> newsList = new ArrayList<>();
        for (long i = 0; i < 10; i++) {
            List<RecommendNewsBean> newsBeanList = this.newsQuartzMapper.noticeRecommendNewsList(i);
            newsList.addAll(newsBeanList);
        }
        logger.info("推送消息给用户，一共{}个用户", newsList.size());
        for (RecommendNewsBean news : newsList) {
            this.pushNews(news);
        }
    }

    /**
     * 将推送的新闻推送给用户
     * @param news 推荐新闻（包含用户信息）
     */
    private void pushNews(RecommendNewsBean news) {
        PushPayloadInfo info = PushPayloadInfo.build(PushMessageEnum.NEWS);
        info.addExtend("newsId", news.getId() + "");
        info.addExtend("title", news.getTitle());
        info.addExtend("isRecommendNews", 2);
        info.addExtend("type", news.getType());

        if (!StringUtils.isEmpty(news.getImgUrl())) {
            List<String> imgs = JSON.parseArray(news.getImgUrl(), String.class);
            if (imgs.size() > 0) {
                info.addExtend("img", imgs.get(0));
            }
        }
        PushMessage pushMessage = PushMessage.build().setPushReceiveScope(PushReceiveScope.pushSignle(news.getUserId()))
                .setPayloadInfo(info)
                .setContent(news.getContent()).setTitle(news.getTitle());

        pushMsgIntegService.pushMsg(pushMessage);
    }


    @Override
    public void publish() {
        List<News> list = newsQuartzMapper.listForPublish(NewsStatusEnum.UNPUBLISHED.getCode());
        for (News news : list) {
            newsQuartzMapper.updateStatusById(news.getId(), NewsStatusEnum.ENABLE.getCode());
        }
    }

    @Override
    public void hotExpire() {
        newsIntegrationService.checkHotNewsExpire();
    }

    @Override
    public void calcParticipantsNum() {
        newsIntegrationService.calcParticipantsNum();
    }

}

==> localnews-quartz-service-1.1.0-sources.jar: com/bxm/localnews/quartz/service/impl/NewsQuartzServiceImpl.java <==
package com.bxm.localnews.quartz.service.impl;

import com.alibaba.fastjson.JSON;
import com.bxm.localnews.common.constant.PushMessageEnum;
import com.bxm.localnews.message.dto.PushMessage;
import com.bxm.localnews.message.dto.PushPayloadInfo;
import com.bxm.localnews.message.service.PushMsgSupplyService;
import com.bxm.localnews.quartz.domain.NewsQuartzMapper;
import com.bxm.localnews.quartz.service.NewsQuartzService;
import com.bxm.localnews.quartz.vo.NewsSearchWordBean;
import com.bxm.localnews.quartz.vo.RecommendNewsBean;
import com.bxm.newidea.component.tools.StringUtils;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class NewsQuartzServiceImpl implements NewsQuartzService {

    private static final Logger logger = LoggerFactory.getLogger(NewsQuartzServiceImpl.class);

    private static String url = "http://top.baidu.com/buzz?b=1&fr=topindex";

    private static String userAgent = "User-Agent";

    private static String value = "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/52.0.2743.116 Safari/537.36";

    private NewsQuartzMapper newsQuartzMapper;

    private PushMsgSupplyService pushMsgSupplyService;

    @Autowired
    public NewsQuartzServiceImpl(NewsQuartzMapper newsQuartzMapper, PushMsgSupplyService pushMsgSupplyService) {
        this.newsQuartzMapper = newsQuartzMapper;
        this.pushMsgSupplyService = pushMsgSupplyService;
    }

    private List<NewsSearchWordBean> loadHotword() {
        List<NewsSearchWordBean> list = new ArrayList<>();
        try {
            Document doc = Jsoup.connect(url).header(userAgent, value).timeout(5000).get();
            Elements elements = doc.select(".keyword");
            for (Element e : elements) {
                if (e == null) {
                    continue;
                }
                Element ee = e.lastElementSibling();
                String name = e.select("a:eq(0)").text();
                String number = ee.select("span").text();
                NewsSearchWordBean word = new NewsSearchWordBean();
                word.setName(name);
                word.setNumber(Integer.valueOf(number));
                list.add(word);
                if (list.size() >= 10) {
                    break;
                }
            }
        } catch (Exception e) {
            logger.error("---抓取热点新闻标题异常---");
        }
        return list;
    }

    @Override
    public void createHotword() {
        List<NewsSearchWordBean> searchWords = loadHotword();
        if (searchWords.size() > 8) {
            newsQuartzMapper.delete();
            newsQuartzMapper.insertBatch(searchWords);
        }
    }

    @Override
    public void execWakeup() {
        List<RecommendNewsBean> newsList = this.newsQuartzMapper.noticeRecommendNewsList();
        for (RecommendNewsBean news : newsList) {
            this.pushNews(news);
        }
    }

    /**
     * 将推送的新闻推送给用户
     * @param news 推荐新闻（包含用户信息）
     */
    private void pushNews(RecommendNewsBean news) {
        PushPayloadInfo info = PushPayloadInfo.build(PushMessageEnum.NEWS);
        info.addExtend("newsId", news.getId() + "");
        info.addExtend("title", news.getTitle());
        info.addExtend("isRecommendNews", 2);
        info.addExtend("type", news.getType());

        if (!StringUtils.isEmpty(news.getImgUrl())) {
            List<String> imgs = JSON.parseArray(news.getImgUrl(), String.class);
            if (imgs.size() > 0) {
                info.addExtend("img", imgs.get(0));
            }
        }
        PushMessage pushMessage = PushMessage.build(null, news.getTitle())
                .setUserId(news.getUserId() + "")
                .setPayloadInfo(info);

        pushMsgSupplyService.pushMsg(pushMessage);
    }

}
